@@ -192,6 +192,15 @@ class Initializer(object):
                 logger.debug("Skipping classloader '{}'".format(loader.toString()))
             loader = loader.getParent()
 
+    @staticmethod
+    def isRunningViaDBCConnect():
+        import pkg_resources as pkg
+        try:
+            pkg.get_distribution('databricks-connect')
+            return True
+        except:
+            return False
+
     @staticmethod
     def getVersion():
         here = path.abspath(path.dirname(__file__))
@@ -208,7 +217,7 @@ class Initializer(object):
         sparkVersionFromPySparkling = pySparklingVersionComponents.sparkMajorMinorVersion
         sparkVersionFromPySpark = pySparkVersionComponents.sparkMajorMinorVersion
 
-        if not (sparkVersionFromPySpark == sparkVersionFromPySparkling):
+        if not Initializer.isRunningViaDBCConnect() and not (sparkVersionFromPySpark == sparkVersionFromPySparkling):
             raise Exception("""
             You are using PySparkling for Spark {}, but your PySpark is of version {}.
             Please make sure Spark and PySparkling versions are compatible.""".format(
